Module pack

Module pack 

Git packfile generation and parsing

Packfiles are git’s binary format for efficiently transferring objects. Format: PACK header, N objects, SHA-1 checksum

Structs

PackBuilder
Thin packfile generation for upload-pack Generates a packfile with only the objects the client needs

Enums

PackObjectType
Pack object type encoding

Functions

generate_packfile
Generate a packfile containing the given objects
parse_packfile
Parse a packfile, storing objects and returning their IDs